Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1337)

Unified Diff: content/browser/frame_host/render_frame_host_impl.h

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: use PreviewsState everywhere Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/render_frame_host_impl.h
diff --git a/content/browser/frame_host/render_frame_host_impl.h b/content/browser/frame_host/render_frame_host_impl.h
index 0d5628798eb26c4c56a43b2fe1323f273e21f6fb..d5073719a654f269ca8f7b79bfee9f2cc24cb336 100644
--- a/content/browser/frame_host/render_frame_host_impl.h
+++ b/content/browser/frame_host/render_frame_host_impl.h
@@ -37,6 +37,7 @@
#include "content/common/navigation_params.h"
#include "content/public/browser/render_frame_host.h"
#include "content/public/common/javascript_message_type.h"
+#include "content/public/common/previews_state.h"
#include "media/mojo/interfaces/interface_factory.mojom.h"
#include "net/http/http_response_headers.h"
#include "services/service_manager/public/cpp/interface_factory.h"
@@ -567,10 +568,10 @@ class CONTENT_EXPORT RenderFrameHostImpl
void SetHasReceivedUserGesture();
- // PlzNavigate: returns the LoFi state of the last successful navigation that
- // made a network request.
- LoFiState last_navigation_lofi_state() const {
- return last_navigation_lofi_state_;
+ // PlzNavigate: returns the Previews state of the last successful navigation
+ // that made a network request.
+ PreviewsState last_navigation_previews_state() const {
+ return last_navigation_previews_state_;
}
protected:
@@ -1049,10 +1050,10 @@ class CONTENT_EXPORT RenderFrameHostImpl
// If true, then the RenderFrame has selected text.
bool has_selection_;
// PlzNavigate: The LoFi state of the last navigation. This is used during
// history navigation of subframes to ensure that subframes navigate with the
- // same LoFi status as the top-level frame.
- LoFiState last_navigation_lofi_state_;
+ // same Previews status as the top-level frame.
+ PreviewsState last_navigation_previews_state_;
mojo::Binding<mojom::FrameHost> frame_host_binding_;
mojom::FramePtr frame_;
@@ -1049,10 +1050,10 @@ class CONTENT_EXPORT RenderFrameHostImpl
// If true, then the RenderFrame has selected text.
bool has_selection_;
- // PlzNavigate: The LoFi state of the last navigation. This is used during
+ // PlzNavigate: The Previews state of the last navigation. This is used during
// history navigation of subframes to ensure that subframes navigate with the

Powered by Google App Engine
This is Rietveld 408576698